
# define to enable Qt5 support (or not)
%global qt5 1

Name:    libmygpo-qt
Summary: Qt4 Library that wraps the gpodder.net Web API
Version: 1.0.8
Release: 5%{?dist}

License: LGPLv2+
Url:     http://wiki.gpodder.org/wiki/Libmygpo-qt
#URL:    https://github.com/gpodder/libmygpo-qt/
Source0: https://github.com/gpodder/libmygpo-qt/archive/1.0.8.tar.gz
#Source0: http://stefan.derkits.at/files/libmygpo-qt/libmygpo-qt.%{version}.tar.gz

# http://bugzilla.redhat.com/1148246
Patch50: libmygpo-qt-1.0.8-INSTALL_DIR.patch

BuildRequires: automoc4
BuildRequires: cmake
BuildRequires: doxygen
BuildRequires: pkgconfig(QJson)
BuildRequires: pkgconfig(QtCore) pkgconfig(QtNetwork) pkgconfig(QtTest)
BuildRequires: pkgconfig(Qt5Core) pkgconfig(Qt5Network)

%description
libmygpo-qt is a Qt4 Library that wraps the gpodder.net Web API,
http://wiki.gpodder.org/wiki/Web_Services/API_2
 
%package devel
Summary: Development files for %{name}
Requires: %{name}%{?_isa} = %{version}-%{release}
%description devel
%{summary}.

%package -n libmygpo-qt5
Summary: Qt5 Library that wraps the gpodder.net Web API
%description -n libmygpo-qt5
libmygpo-qt5 is a Qt5 Library that wraps the gpodder.net Web API,
http://wiki.gpodder.org/wiki/Web_Services/API_2

%package -n libmygpo-qt5-devel
Summary: Development files for libmygpo-qt5
Requires: libmygpo-qt5%{?_isa} = %{version}-%{release}
%description -n libmygpo-qt5-devel
%{summary}.


 
%prep
%setup

%patch50 -p1 -b .INSTALL_DIR


%build
mkdir -p %{_target_platform}
pushd %{_target_platform}
%{cmake} \
  -DBUILD_WITH_QT4:BOOL=ON \
  -DINCLUDE_INSTALL_DIR:PATH=%{_qt4_headerdir}/mygpo-qt \
  -DLIB_INSTALL_DIR:PATH=%{_qt4_libdir}/mygpo-qt \
  ..
popd

make %{?_smp_mflags} -C %{_target_platform}

%if 0%{?qt5}
mkdir -p %{_target_platform}-qt5
pushd %{_target_platform}-qt5
%{cmake} \
  -DBUILD_WITH_QT4:BOOL=OFF \
  -DINCLUDE_INSTALL_DIR:PATH=%{_qt5_headerdir}/mygpo-qt \
  -DLIB_INSTALL_DIR:PATH=%{_qt5_libdir}/mygpo-qt \
  ..
popd

make %{?_smp_mflags} -C %{_target_platform}-qt5
%endif


%install
%if 0%{?qt5}
make install/fast DESTDIR=%{buildroot} -C %{_target_platform}-qt5
%endif
make install/fast DESTDIR=%{buildroot} -C %{_target_platform}


%check
export PKG_CONFIG_PATH=%{buildroot}%{_qt4_libdir}/pkgconfig
test "$(pkg-config --modversion libmygpo-qt)" = "%{version}"
export CTEST_OUTPUT_ON_FAILURE=1
# test 2 currently fails on i686, poke upstream -- rex
make test -C %{_target_platform} ||:
%if 0%{?qt5}
export PKG_CONFIG_PATH=%{buildroot}%{_qt5_libdir}/pkgconfig
test "$(pkg-config --modversion libmygpo-qt5)" = "%{version}"
export CTEST_OUTPUT_ON_FAILURE=1
# test 2 currently fails on i686, poke upstream -- rex
make test -C %{_target_platform}-qt5 ||:
%endif

 
%post -p /sbin/ldconfig
%postun -p /sbin/ldconfig

%files
%doc AUTHORS LICENSE README 
%{_qt4_libdir}/libmygpo-qt.so.1*
 
%files devel
%{_qt4_headerdir}/mygpo-qt/
%{_qt4_libdir}/libmygpo-qt.so
%{_qt4_libdir}/pkgconfig/libmygpo-qt.pc
%dir %{_qt4_libdir}/cmake/mygpo-qt/
%{_qt4_libdir}/cmake/mygpo-qt/Mygpo-qtConfig*.cmake
%{_qt4_libdir}/cmake/mygpo-qt/Mygpo-qtTargets*.cmake

%if 0%{?qt5}
%post -n libmygpo-qt5 -p /sbin/ldconfig
%postun -n libmygpo-qt5 -p /sbin/ldconfig

%files -n libmygpo-qt5
%doc AUTHORS LICENSE README
%{_qt5_libdir}/libmygpo-qt5.so.1*

%files -n libmygpo-qt5-devel
%{_qt5_headerdir}/mygpo-qt/
%{_qt5_libdir}/libmygpo-qt5.so
%{_qt5_libdir}/pkgconfig/libmygpo-qt5.pc
%dir %{_qt5_libdir}/cmake/mygpo-qt/
%{_qt5_libdir}/cmake/mygpo-qt/Mygpo-qt5Config*.cmake
%{_qt5_libdir}/cmake/mygpo-qt/Mygpo-qt5Targets*.cmake
%endif

 
%changelog
* Thu Feb 04 2016 Fedora Release Engineering <releng@fedoraproject.org> - 1.0.8-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_24_Mass_Rebuild

* Wed Jun 17 2015 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.0.8-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_23_Mass_Rebuild

* Sat May 02 2015 Kalev Lember <kalevlember@gmail.com> - 1.0.8-3
- Rebuilt for GCC 5 C++11 ABI change

* Thu Oct 09 2014 Rex Dieter <rdieter@fedoraproject.org> 1.0.8-2
- qt5-devel: fix typo in base pkg dependency

* Wed Oct 01 2014 Rex Dieter <rdieter@fedoraproject.org> 1.0.8-1
- 1.0.8
- include path for cmake and chkconfig are wrong for libmygpo-qt (#1148246)
- use github-hosted sources
- Qt5 support: libmygpo-qt5,libmy-qt5-devel subpkgs

* Sun Aug 17 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.0.7-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_22_Mass_Rebuild

* Sat Jun 07 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.0.7-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_Mass_Rebuild

* Sat Aug 03 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.0.7-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_20_Mass_Rebuild

* Sat Apr 13 2013 Rex Dieter <rdieter@fedoraproject.org> 1.0.7-1
- 1.0.7

* Thu Feb 14 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.0.6-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_19_Mass_Rebuild

* Tue Nov 27 2012 Rex Dieter <rdieter@fedoraproject.org> 1.0.6-3
- rebuild (qjson)

* Fri Nov 23 2012 Rex Dieter <rdieter@fedoraproject.org> 1.0.6-2
- rebuild (qjson)

* Sat Oct 13 2012 Rex Dieter <rdieter@fedoraproject.org> 1.0.6-1
- 1.0.6

* Thu Jul 19 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.0.5-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_18_Mass_Rebuild

* Tue Feb 28 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.0.5-3
- Rebuilt for c++ ABI breakage

* Fri Jan 13 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.0.5-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_17_Mass_Rebuild

* Wed Nov 09 2011 Rex Dieter <rdieter@fedoraproject.org> 1.0.5-1
- 1.0.5

* Wed Sep 14 2011 Rex Dieter <rdieter@fedoraproject.org> 1.0.4-1
- 1.0.4

* Mon May 23 2011 Rex Dieter <rdieter@fedoraproject.org> 1.0.3-1
- 1.0.3

* Fri May 20 2011 Rex Dieter <rdieter@fedoraproject.org> 1.0.2-2
- drop kde deps/macros, this is a qt-only library

* Tue May 10 2011 Rex Dieter <rdieter@fedoraproject.org> 1.0.2-1
- 1.0.2 first try


